==> TSIPPwb1.0.tar.gz: TSIPPwb1.0/tcl/efftcl_extra.tcl <==
# -----------------------------------------------------------------------------
# efftcl_extra.tcl --
#
#       A package of extra procedures to add to the efftcl package, which
#       accompanies the following book:
#
# ----------------------------------------------------------------------
#  Effective Tcl/Tk Programming
#    Mark Harrison, DSC Communications Corp.
#    Michael McLennan, Bell Labs Innovations for Lucent Technologies
#    Addison-Wesley Professional Computing Series
# ======================================================================
#  Copyright (c) 1996-1997  Lucent Technologies Inc. and Mark Harrison
# ======================================================================
# -----------------------------------------------------------------------------
# Copyright 2001 Paul Welton
#       Permission to use, copy, modify, and distribute this software and its
#       documentation for any purpose and without fee is hereby granted,
#       provided that this copyright notice appears in all copies.  No
#       representations are made about the suitability of this software for any
#       purpose.  It is provided "as is" without express or implied warranty.
# -----------------------------------------------------------------------------
# Revision:   1.0   : Initial Release
# -----------------------------------------------------------------------------

package require Efftcl

package provide Efftcl_extra 1.0

#  As Efftcl does not use namespaces, these are not used here for consistency.

# -----------------------------------------------------------------------------
# colordial_get_hsb --
#
#       The base colordial exports its state in RBG format, and provides no
#       means to reload the widget with a previous state.  As the translation
#       from RGB back to HSB is non-trivial and may result in loss of
#       precision, the following routine allows the state to be extracted in
#       HSB format.
#
# Arguments:
#       Window of the colordial widget.
#
# Results:
#       A list of the current HSB values represented by the specified widget.

proc colordial_get_hsb {win} {
    global cdInfo

    set h $cdInfo($win-hue)
    set s $cdInfo($win-saturation)
    set v $cdInfo($win-brightness)

    return [list $h $s $v]
}

# -----------------------------------------------------------------------------
# colordial_set_hsb --
#
#       Companion procedure to "colordial_get_hsb", which allows the state to
#       be reloaded in HSB format, and the graphical representation to be
#       refreshed to reflect that state.
#
# Arguments:
#       Window of the colordial widget and HSB values as discrete arguments.
#
# Results:
#       No return value.

proc colordial_set_hsb {win h s b} {
    global cdInfo

    set cdInfo($win-hue)        $h
    set cdInfo($win-saturation) $s
    set cdInfo($win-brightness) $b

    colordial_refresh $win
    return
}

# ------------------------------------------------------------------------------
# END OF PACKAGE "Efftcl_extra"
# ------------------------------------------------------------------------------

==> TSIPPwb1.3.tar.gz: TSIPPwb1.3/tcl/efftcl_extra.tcl <==
# -----------------------------------------------------------------------------
# efftcl_extra.tcl --
#
#       A package of extra procedures to add to the efftcl package, which
#       accompanies the following book:
#
# ----------------------------------------------------------------------
#  Effective Tcl/Tk Programming
#    Mark Harrison, DSC Communications Corp.
#    Michael McLennan, Bell Labs Innovations for Lucent Technologies
#    Addison-Wesley Professional Computing Series
# ======================================================================
#  Copyright (c) 1996-1997  Lucent Technologies Inc. and Mark Harrison
# ======================================================================
# -----------------------------------------------------------------------------
# Copyright 2001 Paul Welton
#       Permission to use, copy, modify, and distribute this software and its
#       documentation for any purpose and without fee is hereby granted,
#       provided that this copyright notice appears in all copies.  No
#       representations are made about the suitability of this software for any
#       purpose.  It is provided "as is" without express or implied warranty.
# -----------------------------------------------------------------------------
# Revision:   1.0   : Initial Release
# -----------------------------------------------------------------------------

package require Efftcl

package provide Efftcl_extra 1.0

#  As Efftcl does not use namespaces, they are not used here for consistency.

# -----------------------------------------------------------------------------
# colordial_get_hsb --
#
#       The base colordial exports its state in RBG format, and provides no
#       means to reload the widget with a previous state.  As the translation
#       from RGB back to HSB is non-trivial and may result in loss of
#       precision, the following routine allows the state to be extracted in
#       HSB format.
#
# Arguments:
#       win     - pathname of the colordial widget
#
# Results:
#       A list of the current HSB values represented by the specified widget.

proc colordial_get_hsb {win} {
    global cdInfo

    set h $cdInfo($win-hue)
    set s $cdInfo($win-saturation)
    set v $cdInfo($win-brightness)

    return [list $h $s $v]
}

# -----------------------------------------------------------------------------
# colordial_set_hsb --
#
#       Companion procedure to "colordial_get_hsb", which allows the state to
#       be reloaded in HSB format, and the graphical representation to be
#       refreshed to reflect that state.
#
# Arguments:
#       win     - pathname of the colordial widget
#       h, s, b - Hue Saturation and Brightness values as discrete arguments.
#
# Results:
#       No return value.

proc colordial_set_hsb {win h s b} {
    global cdInfo

    set cdInfo($win-hue)        $h
    set cdInfo($win-saturation) $s
    set cdInfo($win-brightness) $b

    colordial_refresh $win
    return
}

# -----------------------------------------------------------------------------
# colordial_state --
#
#       This procedure sets the state of a specified color_dial to either
#       disabled or normal.  When disabled, the control handles become
#       line rather than solid items and the bindings to them are removed.
#
# Arguments:
#       win     - pathname of the colordial widget
#       h, s, b - Hue Saturation and Brightness values as discrete arguments.
#
# Results:
#       No return value.

proc colordial_state {win state} {
    global cdInfo

    if {![info exists cdInfo($win-state)] ||                 \
        ![string equal $state $cdInfo($win-state)]} {
        switch $state {

        disabled {
            #  Capture and store the bindings so that they can be restored
            #  when the state is returned to normal.
            set cdInfo($win-hsval_binding) [$win.dial bind hsval <B1-Motion>]
            set cdInfo($win-bval_binding)  [$win.dial bind bval  <B1-Motion>]

            #  Set the bindings to do nothing.
            $win.dial bind hsval <B1-Motion> { }
            $win.dial bind bval  <B1-Motion> { }

            #  Give the colordial the appearance of being disabled.
            $win.dial itemconfigure hsval -fill {}
            $win.dial itemconfigure bval  -fill {}
        }

        normal {
            #  Restore the bindings.
            $win.dial bind hsval <B1-Motion> $cdInfo($win-hsval_binding)
            $win.dial bind bval  <B1-Motion> $cdInfo($win-bval_binding)

            #  Restore the active appearance of the colordial.
            $win.dial itemconfigure hsval -fill black
            $win.dial itemconfigure bval  -fill black
        }

        default {
            error "Unknown state \"$state\""
        }

        }

        set cdInfo($win-state) $state
    }

    return
}

# -----------------------------------------------------------------------------
# END OF PACKAGE "Efftcl_extra"
# -----------------------------------------------------------------------------
